﻿<# 
.SYNOPSIS 
Download and Parse Dell Downloads from CAB V1.0 - To be used in conjunction with other code for Dell Deployment Solutions
.DESCRIPTION 
Download and Parse Dell Downloads from CAB V1.0 - Created by Mark Godfrey @Geodesicz
.LINK
http://www.tekuits.com
#> 

Param(
    [Parameter(Mandatory=$true,Position=1,HelpMessage="BIOS Password")]
    [ValidateNotNullOrEmpty()]
    [string]$BIOSpassword
)

# Format Cab DL Path
$CabPath = "$PSScriptRoot\dellsdpcatalogpc.cab"

# Download Dell Cab File
Invoke-WebRequest -Uri "http://ftp.dell.com/catalog/dellsdpcatalogpc.cab" -OutFile $CabPath -UseBasicParsing -Verbose
[int32]$n=1
While(!(Test-Path $CabPath) -and $n -lt '3'){
    Invoke-WebRequest -Uri "http://ftp.dell.com/catalog/dellsdpcatalogpc.cab" -OutFile $CabPath -UseBasicParsing -Verbose
    $n++
}

# Extract XML from Cab File
If(Test-Path "$PSScriptRoot\DellSDPCatalogPC.xml"){Remove-Item -Path "$PSScriptRoot\DellSDPCatalogPC.xml" -Force -Verbose}

Expand $CabPath "$PSScriptRoot\DellSDPCatalogPC.xml"

# Import and Create XML Object
If(Test-Path "$PSScriptRoot\DellSDPCatalogPC.xml"){[xml]$XML = Get-Content $PSScriptRoot\DellSDPCatalogPC.xml -Verbose}
else{exit 15}

# Create Array of Downloads
$Downloads = $xml.SystemsManagementCatalog.SoftwareDistributionPackage

# Display List of Available Downloads
# $Names = $Downloads | ForEach {$PSItem.LocalizedProperties.Title}

# Find Target Download for Specific Desired Function (Example)
$Model = ((Get-WmiObject win32_computersystem).Model).TrimEnd()
$Target = $Downloads | Where-Object -FilterScript {$PSitem.LocalizedProperties.Title -match $model}
$TargetLink = $Target.InstallableItem.OriginFile.OriginUri
$TargetFileName = $Target.InstallableItem.OriginFile.FileName
Invoke-WebRequest -Uri $TargetLink -OutFile $PSScriptRoot\$TargetFileName -UseBasicParsing -Verbose
$File = "$PSScriptRoot\$TargetFileName"


<# 
.SYNOPSIS 
Install the Dell Bios File downloaded by Mark's Script Above during WinPE, then Creates Variables for ConfigMgr's TS Process to do additonal tasks (Reboot, etc)
Requires Paramter for Bios Password.  If you don't have a Bios Password, SHAME ON YOU, add one!
.DESCRIPTION 
Take the downloaded BIOS File and Install in WinPE64 - Gary Blok
.LINK
https://garytown.com
#> 


<#Added TS Variables for if using during OSD.  Creates Variable SMSTS_BiosUpdate, and sets to TRUE. (For Future Use)
	http://powershelldistrict.com/how-to-read-and-write-sccm-task-sequence-variables-with-powershell/

#>

$tsenv = New-Object -COMObject Microsoft.SMS.TSEnvironment -ErrorAction SilentlyContinue
$tsenv.Value("SMSTS_BiosUpdate") = "True"

#Create Log Path
$LogPath = $tsenv.Value("_SMSTSLogPath")

#Get Bios File Name (No Extension, used to create Log File)
$BiosLogFileName = $TargetFileName.Replace(".exe",".log")

# Validate BIOS Update File Successful Download
If(!(Test-Path $file)){
    Add-Content -Path "$LogPath\BIOSUpdate_$ComputerModel.log" -Value "BIOS update file did not download correctly"
    $tsenv.Value("SMSTS_BiosUpdateFailedDownload") = "True"
    Exit
}

#Set Command Arguments for Bios Update
$cmds = "/b=$File /s /p=$BiosPassword /l=$LogPath\$BiosLogFileName"

#Update Bios
$Process = start-process $PSScriptRoot\Flash64W.exe -ArgumentList $cmds -PassThru -wait


#Creates and Set TS Variable to be used to run additional steps if reboot requried.
if ($process.ExitCode -eq 2)
    {$tsenv.Value("SMSTS_BiosUpdateRebootRequired") = "True"}
    else
    {$tsenv.Value("SMSTS_BiosUpdateRebootRequired") = "False"}
if ($process.ExitCode -eq 10)
    {$tsenv.Value("SMSTS_BiosUpdateBatteryCharge") = "True"}
    else
    {$tsenv.Value("SMSTS_BiosUpdateBatteryCharge") = "False"}		